@@ -17,7 +17,9 @@ try:
     if TYPE_CHECKING:
         from _bleio import ScanEntry
 
-        LazyObjectField_GivenClass = TypeVar("LazyObjectField_GivenClass")
+        LazyObjectField_GivenClass = TypeVar(  # pylint: disable=invalid-name
+            "LazyObjectField_GivenClass"
+        )
 
 except ImportError:
     pass
@@ -326,7 +328,7 @@ class Advertisement:
         returns ``True`` if at least one of the prefixes match.
         """
         # Returns True if cls.get_prefix_bytes() is empty.
-        return entry.matches(cls.get_prefix_bytes(), all=all_)
+        return entry.matches(cls.get_prefix_bytes(), match_all=all_)
 
     def __bytes__(self) -> bytes:
         """The raw packet bytes."""
